@@ -1,6 +1,6 @@
 package Catalyst::Model::FormFu;
 BEGIN {
-  $Catalyst::Model::FormFu::VERSION = '0.001';
+  $Catalyst::Model::FormFu::VERSION = '0.002';
 }
 
 # ABSTRACT: Speedier interface to HTML::FormFu for Catalyst
@@ -57,7 +57,7 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
-=for :stopwords Peter Shangov precompiled
+=for :stopwords Peter Shangov precompiled BackPAN Daisuke Maki
 
 =head1 NAME
 
@@ -65,7 +65,7 @@ Catalyst::Model::FormFu - Speedier interface to HTML::FormFu for Catalyst
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ C<Catalyst::Model::FormFu> is an alternative interface for using L<HTML::FormFu>
 
 =item *
 
-It initializes all required form objects when your app is started, and returns clones of these objects in your actions. This avoids having to call L<HTML::FormFu/load_config_file> and L<HTML::FormFu/populate> every time you display a form, potentially leading to performance improvements in persistent applications.
+It initializes all required form objects when your app is started, and returns clones of these objects in your actions. This avoids having to call L<HTML::FormFu/load_config_file> and L<HTML::FormFu/populate> every time you display a form, leading to performance improvements in persistent applications.
 
 =item *
 
@@ -122,6 +122,8 @@ It does not inherit from L<Catalyst::Controller>, and so is safe to use with oth
 
 =back
 
+Note that this is a completely different module from the original C<Catalyst::Model::FormFu> by L<Daisuke Maki|http://search.cpan.org/~dmaki/>, which is now only available on the BackPAN (L<http://backpan.perl.org/authors/id/D/DM/DMAKI/Catalyst-Model-FormFu-0.01001.tar.gz>).
+
 =head1 CONFIGURATION OPTIONS
 
 C<Catalyst::Model::FormFu> accepts the following configuration options
